;; Generated package description from indent-bars.el  -*- no-byte-compile: t -*-
(define-package "indent-bars" "0.7.6.0.20241008.83403" "Highlight indentation with bars" '((emacs "27.1") (compat "29.1")) :commit "9de0a02a606789bee9fbcad882552865c4f20725" :authors '(("J.D. Smith" . "jdtsmith+elpa@gmail.com")) :maintainer '("J.D. Smith" . "jdtsmith+elpa@gmail.com") :keywords '("convenience") :url "https://github.com/jdtsmith/indent-bars")
